# Script to find high-quality habitat patches
# Created by San Diego Gnatcatcher Conservation Fund
# On March 15, 2010

import arcpy
import os

arcpy.env.overwriteOutput = True
arcpy.env.workspace = os.path.join(os.path.dirname(os.getcwd()), "data", "Habitat_Analysis.gdb")

roads = "MajorRoads"
veg = "Vegetation"
climate = "ClimateZones"
elev = "Elev_LT_250"
slope = "Slope_LT_40"

# Select vegetation areas with the correct type
select = arcpy.Select_analysis(veg, "in_memory/select", """ "VEG_TYPE" In ('Coastal Sage-Chaparral Scrub', 'Diegan Coastal Sage Scrub', 'Maritime Succulent Scrub')""")

# Buffer roads to exclude these areas
buffer = arcpy.Buffer_analysis(roads, "in_memory/buffer", "1000 Feet", "", "", "ALL")

# Remove the buffered roads from the the suitable vegetation areas
erase = arcpy.Erase_analysis(select, buffer, "in_memory/erase")

# Find all the areas that match the climate, slope, elevation, and vegetation criteria by performing Intersect
intersect = arcpy.Intersect_analysis([climate, slope, elev, erase], "in_memory/intersect")

# Dissolve the areas
dissolve = arcpy.Dissolve_management(intersect, "in_memory/dissolve", "Climate", "", "SINGLE_PART")

# Add an attribute field and calculate the area of the contiguous habitat patches in acres
arcpy.AddField_management(dissolve, "Area", "Double")
arcpy.CalculateField_management(dissolve, "Area", "!Shape.Area@acres!", "PYTHON")

# Find patches that are larger than 100 acres in the Coastal zone
habitat = arcpy.Select_analysis(dissolve, "Habitat", """ "Area" >100 AND "Climate" = 'Coastal' """)

print "Finished"
